/*
 * Quoridor server and related libraries
 * Copyright (C) 2009-2010 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */

package cz.xelfi.quoridor.webidor;

import cz.xelfi.quoridor.webidor.resources.Games;
import cz.xelfi.quoridor.webidor.resources.Quoridor;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ResourceBundle;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class GamesTest extends Object {
    static {
        System.setProperty("JERSEY_HTTP_PORT", "33436");
    }
    private File dir;

    @Before
    public void setUp() throws Exception {
        dir = File.createTempFile("quoridor", ".dir");
        deleteRec(dir);
        dir.mkdirs();
        System.setProperty("quoridor.dir", dir.getPath());
    }

    @After
    public void tearDown() throws Exception {
        deleteRec(dir);
    }

    static void deleteRec(File dir) throws IOException {
        if (dir == null) {
            return;
        }
        File[] arr = dir.listFiles();
        if (arr != null) {
            for (File f : arr) {
                deleteRec(f);
            }
        }
        dir.delete();
    }

    @Test public void testCreateAGame() throws Exception {
        File f = new File(new File(dir, "games"), "x");
        f.getParentFile().mkdirs();
        FileOutputStream os = new FileOutputStream(f);
        os.write("# white: W\n# black: B\n# status: IN_PROGRESS\nN S\n\n".getBytes("UTF-8"));
        os.close();

        Thread.sleep(1000);
        
        long middle = f.lastModified();

        Thread.sleep(1000);

        Games games = new Games(f.getParentFile(), new Quoridor());
        Game g = games.getBoardInfo("", "x", -1);
        assertNotNull("Game found", g);
        assertNotNull("Board found", g.getBoard());
        assertEquals("List of moves has two", 2, g.getMoves().size());

        assertEquals("Last move is last touch of the file", middle, g.getId().getModified());
    }

    @Test public void testLoadGameWithComments() throws Exception {
        File f = new File(new File(dir, "games"), "x");
        f.getParentFile().mkdirs();
        FileOutputStream os = new FileOutputStream(f);
        os.write("# white: W\n# black: B\n# status: IN_PROGRESS\nN #good move\n... S # ok move\n\n".getBytes("UTF-8"));
        os.close();

        Thread.sleep(1000);

        long middle = f.lastModified();

        Thread.sleep(1000);

        Games games = new Games(f.getParentFile(), new Quoridor());
        Game g = games.getBoardInfo("", "x", -1);
        assertNotNull("Game found", g);
        assertNotNull("Board found", g.getBoard());
        assertEquals("List of moves has two", 2, g.getMoves().size());

        assertEquals("Last move is last touch of the file", middle, g.getId().getModified());
    }

    @Test public void testLoadGameWithInternationalComments() throws Exception {
        File f = new File(new File(dir, "games"), "x");
        f.getParentFile().mkdirs();
        FileOutputStream os = new FileOutputStream(f);
        ResourceBundle b = ResourceBundle.getBundle("cz/xelfi/quoridor/webidor/TestBundle");
        String comment = b.getString("COMMENT");
        os.write(("# white: W\n# black: B\n# status: IN_PROGRESS\nN\n#" +
                comment + "\n... S # ok move\n\n").getBytes("UTF-8"));
        os.close();

        Thread.sleep(1000);

        long middle = f.lastModified();

        Thread.sleep(1000);

        Games games = new Games(f.getParentFile(), new Quoridor());
        Game g = games.getBoardInfo("", "x", -1);
        assertNotNull("Game found", g);
        assertNotNull("Board found", g.getBoard());
        assertEquals("List of moves has two", 2, g.getMoves().size());
        String commentRead = g.getMoves().get(0).getComments().get(0).getComment();
        assertEquals(comment, commentRead);

        assertEquals("Last move is last touch of the file", middle, g.getId().getModified());
    }

}
