/*
 * Quoridor server and related libraries
 * Copyright (C) 2009-2010 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */

package cz.xelfi.quoridor.webidor;

import cz.xelfi.quoridor.Board;

/** Possible states of the game.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public enum GameStatus {
    whiteMove,
    blackMove,
    whiteWon,
    blackWon,
    history;

    /** Creates appropriate status of the game based on the state
     * on the board.
     *
     * @param board the board
     * @return status describing the situation on the board
     */
    public static GameStatus valueOf(Board board) {
        if (board.getWinner() != null) {
            return board.getWinner() == board.getPlayers().get(0) ? GameStatus.whiteWon : GameStatus.blackWon;
        } else {
            return board.getCurrentPlayer() == board.getPlayers().get(0) ? GameStatus.whiteMove : GameStatus.blackMove;
        }
    }

    /** @return true if the game is in progress
     */
    public boolean isInProgress() {
        return this == whiteMove || this == blackMove;
    }
}
